==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/SmsChannelPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.SmsChannelPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The parameters to provide for the Sms channel.
 * @property accountSID The Sms account SID. Value only returned through POST to the action Channel List API, otherwise empty.
 * @property authToken The Sms auth token. Value only returned through POST to the action Channel List API, otherwise empty.
 * @property isEnabled Whether this channel is enabled for the bot
 * @property isValidated Whether this channel is validated for the bot
 * @property phone The Sms phone
 */
public data class SmsChannelPropertiesArgs(
    public val accountSID: Output<String>,
    public val authToken: Output<String>? = null,
    public val isEnabled: Output<Boolean>,
    public val isValidated: Output<Boolean>? = null,
    public val phone: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.SmsChannelPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.SmsChannelPropertiesArgs =
        com.pulumi.azurenative.botservice.inputs.SmsChannelPropertiesArgs.builder()
            .accountSID(accountSID.applyValue({ args0 -> args0 }))
            .authToken(authToken?.applyValue({ args0 -> args0 }))
            .isEnabled(isEnabled.applyValue({ args0 -> args0 }))
            .isValidated(isValidated?.applyValue({ args0 -> args0 }))
            .phone(phone.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SmsChannelPropertiesArgs].
 */
@PulumiTagMarker
public class SmsChannelPropertiesArgsBuilder internal constructor() {
    private var accountSID: Output<String>? = null

    private var authToken: Output<String>? = null

    private var isEnabled: Output<Boolean>? = null

    private var isValidated: Output<Boolean>? = null

    private var phone: Output<String>? = null

    /**
     * @param value The Sms account SID. Value only returned through POST to the action Channel List API, otherwise empty.
     */
    @JvmName("wycmwtahijcqqahm")
    public suspend fun accountSID(`value`: Output<String>) {
        this.accountSID = value
    }

    /**
     * @param value The Sms auth token. Value only returned through POST to the action Channel List API, otherwise empty.
     */
    @JvmName("gkvhutjmpasxjswk")
    public suspend fun authToken(`value`: Output<String>) {
        this.authToken = value
    }

    /**
     * @param value Whether this channel is enabled for the bot
     */
    @JvmName("hovxhjtudegjifbt")
    public suspend fun isEnabled(`value`: Output<Boolean>) {
        this.isEnabled = value
    }

    /**
     * @param value Whether this channel is validated for the bot
     */
    @JvmName("papwsaqjctajkops")
    public suspend fun isValidated(`value`: Output<Boolean>) {
        this.isValidated = value
    }

    /**
     * @param value The Sms phone
     */
    @JvmName("swoirfmtaihlvgkl")
    public suspend fun phone(`value`: Output<String>) {
        this.phone = value
    }

    /**
     * @param value The Sms account SID. Value only returned through POST to the action Channel List API, otherwise empty.
     */
    @JvmName("vcqcygiuytvxpxct")
    public suspend fun accountSID(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.accountSID = mapped
    }

    /**
     * @param value The Sms auth token. Value only returned through POST to the action Channel List API, otherwise empty.
     */
    @JvmName("nnrffsdpeobivjls")
    public suspend fun authToken(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authToken = mapped
    }

    /**
     * @param value Whether this channel is enabled for the bot
     */
    @JvmName("maobwwqvwrxvgbtq")
    public suspend fun isEnabled(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.isEnabled = mapped
    }

    /**
     * @param value Whether this channel is validated for the bot
     */
    @JvmName("cueqxwmuubhrerje")
    public suspend fun isValidated(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isValidated = mapped
    }

    /**
     * @param value The Sms phone
     */
    @JvmName("cuyxmaxkuerrtsil")
    public suspend fun phone(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.phone = mapped
    }

    internal fun build(): SmsChannelPropertiesArgs = SmsChannelPropertiesArgs(
        accountSID = accountSID ?: throw PulumiNullFieldException("accountSID"),
        authToken = authToken,
        isEnabled = isEnabled ?: throw PulumiNullFieldException("isEnabled"),
        isValidated = isValidated,
        phone = phone ?: throw PulumiNullFieldException("phone"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/SmsChannelPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.SmsChannelPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The parameters to provide for the Sms channel.
 * @property accountSID The Sms account SID. Value only returned through POST to the action Channel List API, otherwise empty.
 * @property authToken The Sms auth token. Value only returned through POST to the action Channel List API, otherwise empty.
 * @property isEnabled Whether this channel is enabled for the bot
 * @property isValidated Whether this channel is validated for the bot
 * @property phone The Sms phone
 */
public data class SmsChannelPropertiesArgs(
    public val accountSID: Output<String>,
    public val authToken: Output<String>? = null,
    public val isEnabled: Output<Boolean>,
    public val isValidated: Output<Boolean>? = null,
    public val phone: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.SmsChannelPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.SmsChannelPropertiesArgs =
        com.pulumi.azurenative.botservice.inputs.SmsChannelPropertiesArgs.builder()
            .accountSID(accountSID.applyValue({ args0 -> args0 }))
            .authToken(authToken?.applyValue({ args0 -> args0 }))
            .isEnabled(isEnabled.applyValue({ args0 -> args0 }))
            .isValidated(isValidated?.applyValue({ args0 -> args0 }))
            .phone(phone.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SmsChannelPropertiesArgs].
 */
@PulumiTagMarker
public class SmsChannelPropertiesArgsBuilder internal constructor() {
    private var accountSID: Output<String>? = null

    private var authToken: Output<String>? = null

    private var isEnabled: Output<Boolean>? = null

    private var isValidated: Output<Boolean>? = null

    private var phone: Output<String>? = null

    /**
     * @param value The Sms account SID. Value only returned through POST to the action Channel List API, otherwise empty.
     */
    @JvmName("ixuivxmtkhesdpiw")
    public suspend fun accountSID(`value`: Output<String>) {
        this.accountSID = value
    }

    /**
     * @param value The Sms auth token. Value only returned through POST to the action Channel List API, otherwise empty.
     */
    @JvmName("pmvofuioyovavnfs")
    public suspend fun authToken(`value`: Output<String>) {
        this.authToken = value
    }

    /**
     * @param value Whether this channel is enabled for the bot
     */
    @JvmName("vgtmgtechsulencc")
    public suspend fun isEnabled(`value`: Output<Boolean>) {
        this.isEnabled = value
    }

    /**
     * @param value Whether this channel is validated for the bot
     */
    @JvmName("rlfmiydgwpwrtejb")
    public suspend fun isValidated(`value`: Output<Boolean>) {
        this.isValidated = value
    }

    /**
     * @param value The Sms phone
     */
    @JvmName("sbnmsqtuptvwyiph")
    public suspend fun phone(`value`: Output<String>) {
        this.phone = value
    }

    /**
     * @param value The Sms account SID. Value only returned through POST to the action Channel List API, otherwise empty.
     */
    @JvmName("tuffmryudthevtig")
    public suspend fun accountSID(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.accountSID = mapped
    }

    /**
     * @param value The Sms auth token. Value only returned through POST to the action Channel List API, otherwise empty.
     */
    @JvmName("swpxfgxuxkrnaudu")
    public suspend fun authToken(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authToken = mapped
    }

    /**
     * @param value Whether this channel is enabled for the bot
     */
    @JvmName("eyjychaeogrbmwed")
    public suspend fun isEnabled(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.isEnabled = mapped
    }

    /**
     * @param value Whether this channel is validated for the bot
     */
    @JvmName("ulpfnbjoancoyuha")
    public suspend fun isValidated(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isValidated = mapped
    }

    /**
     * @param value The Sms phone
     */
    @JvmName("mmkgnfdvkylwqwdf")
    public suspend fun phone(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.phone = mapped
    }

    internal fun build(): SmsChannelPropertiesArgs = SmsChannelPropertiesArgs(
        accountSID = accountSID ?: throw PulumiNullFieldException("accountSID"),
        authToken = authToken,
        isEnabled = isEnabled ?: throw PulumiNullFieldException("isEnabled"),
        isValidated = isValidated,
        phone = phone ?: throw PulumiNullFieldException("phone"),
    )
}
